program define medianize, eclass properties(svyb mi)
/*******************************************************

MEDIANIZE - calculate a median

This Stata command estimates the median and can be combined 
with the svy and mi commands, only with replicate weights.

Syntax: syntax varlist [weight] [if] [in] [, over(varname) Statistic(string)] 

In order to combine with mi and svy, only one variable can 
be given in varlist.

Statistic is any statistic accepter by tabstat.

ECB - v 0.2 2012/07/13 - Sbastien Perez-Duarte

*******************************************************/

    syntax varlist [aweight iweight pweight] [if] [in] [,over(varname) Statistic(string)] 
    
    marksample touse
    if "`weight'"!="" local weight="aweight" 
	
	* statistic by default - the median
    if "`statistic'"=="" local statistic="p50"
	
	/* calculate the statistic of interest with tabstat */
	tabstat `varlist' [`weight'`exp'] if `touse', s(`statistic')  by(`over') save

	matrix _zz=r(Stat1)
	
	if _zz[1,1]==. matrix _zz=r(StatTotal)
	
	capture matrix drop _z

	/* construct the e(b) output and assign the correct colnames */
	local i=1
	local names
	while _zz[1,1] ~= . {
		if "`i'"=="1" matrix _z=_zz
		else matrix _z=_z,_zz

		local names="`names' `r(name`i')'"
		
		local ++i
		matrix _zz=r(Stat`i')
	}
	
	matrix colnames _z = `names'
	
	/* the sample used */
	gen one= `touse'
	ereturn post _z, esample(one)

	/* arguments required by svy and mi */
	ereturn local cmd medianize
	ereturn local title "Medianize `statistic'"

	quiet count if `touse'
	ereturn local N r(N)

	capture matrix drop _z _zz
end
