********************************************************************
***Merging the files of the HFCS data
********************************************************************

*Set macro for the path to the data (must be specified by the user)
global hfcsdata="path to the appropriate folder where the data are stored"

*Set macro for the path to the do-files (must be specified by the user)
global hfcsdofile="path to the appropriate folder where the do-files are stored"

*Set working directory
cd "$hfcsdata"

*Merging the p and h files together (wide format)
forvalues i=1(1)5 {
	use "$hfcsdata\P`i'.dta", clear
	drop id hid survey
	capture drop ra0020 fra0020 ra0030 fra0030 ra0040 fra0040 
	foreach var of varlist  sa0010- fra0500 {
		local `var'lab: variable label `var'
	}
	reshape wide ra0?0* fra0?0* p* fp*  , i(sa0010 sa0100) j( ra0010)
	foreach j of varlist ra* fra* p* fp* {
		local last2car=substr("`j'", `=length("`j'")-1', 1)
		local last1car=substr("`j'", length("`j'"), 1)
		if "`last2car'"=="1" {
			local firstcar=substr("`j'",1, `=length("`j'")-2')
			rename `j' `firstcar'_`last2car'`last1car'
			label variable `firstcar'_`last2car'`last1car' "``firstcar'lab' - `last2car'`last1car'"
		}
		else {
			local firstcar=substr("`j'",1, `=length("`j'")-1')
			rename `j' `firstcar'_`last1car'
			label variable `firstcar'_`last1car' "``firstcar'lab' - `last1car'"
		}
	}
	save "$hfcsdata\P`i'_temp.dta", replace
	clear
	use "$hfcsdata\H`i'.dta", clear
	merge 1:1 sa0010 sa0100 im0100 using "$hfcsdata\P`i'_temp.dta", nogen
	save "$hfcsdata\M`i'.dta", replace
	erase "$hfcsdata\P`i'_temp.dta"
}

*Merging the core with the derived variables
forvalues i=1(1)5 {
	use "$hfcsdata\M`i'.dta", clear
	merge 1:1 sa0010 im0100 sa0100 using "$hfcsdata\D`i'.dta"
	save "$hfcsdata\temp`i'.dta", replace
}

*Merging the implicates together(see note in the chapter!)
use "$hfcsdata\temp1.dta", clear
forvalues j=2(1)5 {
	append using "$hfcsdata\temp`j'.dta"
}

*Drop unnecessary variables and labels
drop _merge
label drop _merge

*Save the HFCS data
save "$hfcsdata\hfcs.dta", replace



********************************************************************
***Preparing the data for mi import
********************************************************************

*Create the zero implicate to simulate the original data
*Use one implicate of the data
use "$hfcsdata\temp1.dta", clear
*Replace the implicate number by 0 to simulate the original data
replace im0100=0
*Append all other implicates
append using "$hfcsdata\hfcs.dta"


*For some reason string variables do not play well with mi commands and need to be encoded into numeric variables
foreach var of varlist hb* hc* hd* hg* hh* hi* pa* pe* pf* pg* ra* sa0100 sb1000 {
	capture confirm numeric variable `var'
	if _rc {
		rename `var' `var'_string
		encode `var'_string, gen(`var')
		drop `var'_string
	}
}


*Set as soft missing (".") in im0100==0 all values varying, and also those whose flags set them as imputed
global IMPUTEDVARS=""
foreach var of varlist hb* hc* hd* hg* hh* hi* pa* pe* pf* pg* ra* {
	capture confirm numeric variable `var'
	if !_rc {
		tempvar sd count
		quietly bysort sa0100 sa0010 : egen `sd'=sd(`var')
		quietly bysort sa0100 sa0010 : egen `count'=count(`var')
		quietly count if ( (`sd'>0 & `sd' <. ) | `count'<6 | (f`var'>4000 & f`var'<5000) ) & im0100==0
		if r(N)>0 global IMPUTEDVARS "$IMPUTEDVARS `var'"
		quietly replace `var'=. if ( (`sd'>0 & `sd' <. ) | `count'<6 | (f`var'>4000 & f`var'<5000) ) & im0100==0 
		drop `sd' `count'
		disp ".", _continue
	}
}

*Drop unnecessary variables
drop id _merge

*Save the HFCS data
save "$hfcsdata\hfcs.dta", replace

*Erase temporary files that will not be needed anymore
forvalues i=1(1)5 {
	erase "$hfcsdata\temp`i'.dta"
}

********************************************************************
*****Import as multiply imputed data
********************************************************************

*Import the imputation structure of the data into Stata
mi import flong, m(im0100) id(sa0100 sa0010) clear

*Register the variables that are imputed
mi register imputed $IMPUTEDVARS

*Check whether all imputed variables are registered
mi varying

*Save the HFCS-data with mi structure
save "$hfcsdata\hfcs.dta", replace



********************************************************************
***Setting up Complex Survey Design
********************************************************************

*Encode country indicator
use "$hfcsdata\W.dta", clear 
rename sa0100 sa0100_string
encode sa0100_string, gen(sa0100)
drop sa0100_string
save "$hfcsdata\Wtemp.dta", replace


*Using the HFCS data with mi structure
use "$hfcsdata\hfcs.dta", clear 

*Merging the data with replicate weights
merge m:1 sa0100 sa0010 using "$hfcsdata\Wtemp.dta"

*Drop unnecessary variable and files
drop _merge
erase "$hfcsdata\Wtemp.dta"

*Setting the appropriate survey structure using replicate weights
mi svyset [pw=hw0010], bsrweight(wr0001-wr1000) vce(bootstrap)

*Save the HFCS-data with mi svyset structure
save "$hfcsdata\hfcs.dta", replace



********************************************************************
***Using Standard Estimation Procedures
********************************************************************

*Using the HFCS-data with mi svyset structure
use "$hfcsdata\hfcs.dta", clear 

*Modified Stata command, which should be run before the estimation commands for versions of Stata previous to Stata 12 (always update to the most recent Stata version). Furthermore, exclude in this case the vceok option in the estimations below.
*do "$hfcsdofile\modified u_mi_estimate 11.2.do"

*Mean of current value of primary housing unit
mi estimate, esampvaryok vceok: svy: mean hb0900
*Mean of current value of primary housing unit for part owner of the primary housing unit
gen partowner=(hb0300==2)
mi estimate, esampvaryok vceok: svy, subpop(partowner): mean hb0900
*Proportions of owner/renter of primary housing unit
mi estimate, esampvaryok vceok: svy: proportion hb0300
*Ratio of current to acquisition value of primary housing unit
mi estimate, esampvaryok vceok: svy: ratio hb0900 hb0800
*Regression of current value of primary housing on acquisition value and year of acquisition
mi estimate, esampvaryok vceok: svy: regress hb0900 hb0800 hb0700
*Average level deposits according to gender of the first person
mi estimate, esampvaryok vceok: svy: mean  da2101, over(ra0200_1)



********************************************************************
***Including Additional Estimation Procedures
********************************************************************

*ECB-written command to calculate medians (and some other quantile statistics), which should be run before the estimation command
capture program drop
do "$hfcsdofile\medianize.do"

*Median of amount still owned in the first loan collateralized with primary housing unit
mi estimate, esampvaryok vceok: svy: medianize hb1701
*Median of amount still owned in the first loan collateralized with primary housing unit over gender of first person
mi estimate, esampvaryok vceok: svy: medianize hb1701, over(ra0200_1)
*Median of amount still owned in the first loan collateralized with primary housing unit over gender of first person
mi estimate, esampvaryok vceok: svy: medianize hb1701, over(ra0200_1) stat(p10)


********************************************************************
***Do-File History
********************************************************************
*Version 1.0: published for the release of the first wave of the HFCS-data February 2013
*Version 1.1: correction of inclusion of panel variables (ra0020 fra0020 ra0030 fra0030 ra0040 fra0040) not needed for the first wave (thanks to Paul Eckerstorfer for pointing it out) [new line 18; published October 2013]
